@@ -24,9 +24,12 @@
 	 *
 	 *--------------------------------------------------------------*/
 
-#include "addpfx.h"
+
+#include <string.h>
+
 #include "tlf.h"
 
+
 int nr_of_px = 0;
 int nr_of_px_ab = 0;
 
