@@ -24,10 +24,19 @@
 	 *
 	 *
 	 *--------------------------------------------------------------*/
-#include "addspot.h"
-#include "tlf.h"
+
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+
+#include "get_time.h"
+#include "lancode.h"
 #include "splitscreen.h"
-#include "get_time.h" 
+#include "tlf.h"
+#include "tlf_curses.h"
+
 
 int addspot(void)
 {
