@@ -22,14 +22,20 @@
 	 *
 	 *--------------------------------------------------------------*/
 
-#include "autocq.h"
-#include "tlf.h"
-#include "printcall.h"
+
+#include <string.h>
+#include <unistd.h>
+
 #include "clear_display.h"
+#include "cw_utils.h"
+#include "printcall.h"
 #include "sendbuf.h"
 #include "stoptx.h"
-#include "cw_utils.h"
+#include "tlf.h"
+#include "tlf_curses.h"
 #include "ui_utils.h"
+#include "time_update.h"
+
 
 int play_file(char *audiofile);
 
@@ -71,6 +77,7 @@ int auto_cq(void)
 	    message_time = (long) (1200.0 / realspeed) * cw_message_len;
 	    for (j = 0; j < 10; j++) {
 		usleep(message_time * 100);
+		time_update();
 		inchar = key_poll();
 		if (inchar > 0) {
 		    letter = inchar;
@@ -86,8 +93,8 @@ int auto_cq(void)
 	    } else {
 		break;
 	    }
-
 	    usleep(500000);
+	    time_update();
 
 	    if (inchar < 0)
 		inchar = key_poll();
