@@ -17,30 +17,20 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "bandmap.h"
-#include "tlf.h"
-#include "searchcallarray.h"
-#include "getctydata.h"
-#include "showinfo.h"
-#include "searchlog.h"
-#include "ui_utils.h"
-#include "qtcvars.h"
 
-#include <math.h>
-#include <glib.h>
-#include <ncurses.h>
+#include <ctype.h>
 #include <pthread.h>
-
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <sys/time.h>
 
-#ifdef HAVE_LIBHAMLIB
-#include <hamlib/rig.h>
-#endif
-
+#include "bandmap.h"
 #include "qtcutil.h"
+#include "qtcvars.h"		// Includes globalvars.h
+#include "searchcallarray.h"
+#include "tlf_curses.h"
+#include "ui_utils.h"
 
 #define TOLERANCE 100 		/* spots with a QRG +/-TOLERANCE
 				   will be counted a s the same QRG */
@@ -119,11 +109,12 @@ gint cmp_freq(spot *a, spot *b);
 /*
  * write bandmap spots to a file
  */
-void bmdata_write_file(int last_bm_save_time) {
+void bmdata_write_file() {
 
     FILE * fp;
     spot * sp;
     GList *found;
+    struct timeval tv;
 
     if ((fp = fopen(".bmdata.dat", "w")) == NULL) {
 	attron(modify_attr(COLOR_PAIR(CB_DUPE)|A_BOLD));
@@ -131,15 +122,23 @@ void bmdata_write_file(int last_bm_save_time) {
 	refreshp();
 	return;
     }
+
+    gettimeofday(&tv, NULL);
+
+    pthread_mutex_lock( &bm_mutex );
+
     found = allspots;
-    fprintf(fp, "%d\n", last_bm_save_time);
+    fprintf(fp, "%d\n", (int)tv.tv_sec);
     while (found != NULL) {
 	sp = found->data;
-	fprintf(fp, "%s;%d;%d;%d;%c;%d;%d\n",
+	fprintf(fp, "%s;%d;%d;%d;%c;%u;%d\n",
 		sp->call, sp->freq, sp->mode, sp->band,
 		sp->node, (int)sp->timeout, sp->dupe);
 	found = found->next;
     }
+
+    pthread_mutex_unlock( &bm_mutex );
+
     fclose(fp);
 }
 
@@ -160,6 +159,9 @@ void bmdata_read_file() {
 	    sscanf(line, "%d", &last_bm_save_time);
 	    gettimeofday(&tv, NULL);
 	    timediff = (int)tv.tv_sec - last_bm_save_time;
+	    if (timediff < 0)
+		timediff = 0;
+
 	    while (fgets(line, 50, fp)) {
 	        spot *entry = g_new0(spot, 1);
 		fc = 0;
@@ -177,8 +179,7 @@ void bmdata_read_file() {
 					break;
 			case 4:		sscanf(token, "%c", &entry->node);
 					break;
-			case 5:		sscanf(token, "%d", &entry->timeout);
-					entry->timeout -= timediff;
+			case 5:		sscanf(token, "%u", &entry->timeout);
 					break;
 			case 6:		sscanf(token, "%hhd", &entry->dupe);
 					break;
@@ -186,7 +187,8 @@ void bmdata_read_file() {
 		    fc++;
 		    token = strtok (NULL, ";");
 		}
-		if (entry->timeout > 0) {
+		if (entry->timeout > timediff) {
+		    entry->timeout -= timediff;	/* remaining time */
 		    allspots = g_list_insert_sorted( allspots, entry, (GCompareFunc)cmp_freq);
 		} else {
 		    g_free(entry);
@@ -306,8 +308,6 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
     GList *found;
     int band;
     char mode;
-    struct timeval tv;
-    static int last_bm_save_time = 0;
 
     /* add only HF spots */
     if (freq > 30000000)
@@ -384,14 +384,6 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
 	g_free (olddata);
     }
 
-    gettimeofday(&tv, NULL);
-    if (last_bm_save_time == 0) {
-	last_bm_save_time = (int)tv.tv_sec;
-    }
-    if ((int)tv.tv_sec > last_bm_save_time+10) {
-	last_bm_save_time = (int)tv.tv_sec;
-	bmdata_write_file(last_bm_save_time);
-    }
 
     pthread_mutex_unlock( &bm_mutex );
 }
@@ -415,11 +407,11 @@ void bandmap_age() {
 	list = list->next;
 	if (data->timeout) {
 	    data->timeout--;
-	    if (data->timeout == 0) {
-		allspots = g_list_remove_link( allspots, temp);
-		g_free (data->call);
-		g_free (data);
-	    }
+	}
+	if (data->timeout == 0) {
+	    allspots = g_list_remove_link( allspots, temp);
+	    g_free (data->call);
+	    g_free (data);
 	}
     }
 
