@@ -23,12 +23,16 @@
      *
      *--------------------------------------------------------------*/
 
-#include "calledit.h"
-#include "tlf.h"
-#include "ui_utils.h"
-#include "searchlog.h"
+
+#include <string.h>
+
 #include "getctydata.h"
+#include "searchlog.h"		// Includes glib.h
 #include "showinfo.h"
+#include "tlf.h"
+#include "tlf_curses.h"
+#include "ui_utils.h"
+
 
 void calledit(void)
 {
