@@ -24,34 +24,29 @@
 	 *
 	 *--------------------------------------------------------------*/
 
-#include "getexchange.h"
-#include "tlf.h"
-#include "time_update.h"
-#include "recall_exchange.h"
+
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
 #include "addspot.h"
-#include "logit.h"
 #include "cw_utils.h"
-#include <glib.h>
-#include "qtcwin.h"
-#include "locator2longlat.h"
-#include "score.h"
-#include "searchlog.h"
-#include "clear_display.h"
-#include "stoptx.h"
-#include "displayit.h"
-#include "speedupndown.h"
-#include "sendbuf.h"
-#include "scroll_log.h"
-#include "addcall.h"
-#include "makelogline.h"
-#include "store_qso.h"
-#include "qsonr_to_str.h"
-#include "writeparas.h"
-#include "lancode.h"
 #include "keyer.h"
+#include "lancode.h"
+#include "locator2longlat.h"
+#include "logit.h"
+#include "qtcvars.h"		// Includes globalvars.h
+#include "qtcwin.h"
+#include "recall_exchange.h"
 #include "rtty.h"
+#include "score.h"
+#include "searchlog.h"		// Includes glib.h
+#include "sendbuf.h"
+#include "speedupndown.h"
+#include "stoptx.h"
+#include "time_update.h"
+#include "tlf_curses.h"
 #include "ui_utils.h"
-#include "qtcvars.h"
 
 #define MULTS_POSSIBLE(n) ((char *)g_ptr_array_index(mults_possible, n))
 #define LEN(array) (sizeof(array) / sizeof(array[0]))
