@@ -22,15 +22,21 @@
 	 *
 	 *--------------------------------------------------------------*/
 
+
+#include <unistd.h>
+
+#include "fldigixmlrpc.h"
 #include "gettxinfo.h"
 #include "tlf.h"
-#include "sendqrg.h"
-#include "fldigixmlrpc.h"
+#include "tlf_curses.h"
 
-#ifdef HAVE_LIBHAMLIB
-#include <hamlib/rig.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
 #endif
 
+#ifdef HAVE_LIBHAMLIB
+# include <hamlib/rig.h>
+#endif
 
 int gettxinfo(void)
 {
@@ -48,14 +54,19 @@ int gettxinfo(void)
 
     extern int trx_control;
     extern int trxmode;
+    extern int rigmode;
+    extern int keyerport;
 
 #ifdef HAVE_LIBHAMLIB
     freq_t rigfreq;
     vfo_t vfo;
+    pbwidth_t bwidth;
+    int retval;
+    int retvalmode;
 #else
     float rigfreq;
 #endif
-    int retval = 0;
+
     static int oldbandinx;
 
     void send_bandswitch(int freq);
@@ -69,10 +80,19 @@ int gettxinfo(void)
 
 #ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
 	retval = rig_get_vfo(my_rig, &vfo); /* initialize RIG_VFO_CURR */
-	if (retval == RIG_OK || retval == -RIG_ENIMPL || retval == -RIG_ENAVAIL)
+	if (retval == RIG_OK || retval == -RIG_ENIMPL || retval == -RIG_ENAVAIL) {
 	    retval = rig_get_freq(my_rig, RIG_VFO_CURR, &rigfreq);
+	    if (trxmode == DIGIMODE && keyerport == GMFSK && retval == RIG_OK) {
+		retvalmode = rig_get_mode(my_rig, RIG_VFO_CURR, (rmode_t *)&rigmode, &bwidth);
+		if (retvalmode != RIG_OK) {
+		    rigmode = RIG_MODE_NONE;
+		}
+	    }
+	}
 
-	rigfreq += fldigi_get_carrier();
+	if (trxmode == DIGIMODE && keyerport == GMFSK) {
+	    rigfreq += fldigi_get_carrier();
+	}
 
 	if (retval != RIG_OK || rigfreq < 0.1) {
 	    freq = 0.0;
