@@ -19,24 +19,54 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "tlf.h"
-#include "globalvars.h"
-#include "main.h"
-#include "searchlog.h"
-#include "cw_utils.h"
-#include <glib.h>
-#include <panel.h>
+
+#include <ctype.h>
 #include <pthread.h>
+#include <stdlib.h>
+#include <string.h>
+#include <termios.h>
+#include <unistd.h>
+
+#include "addmult.h"
+#include "background_process.h"
+#include "bandmap.h"
+#include "checkparameters.h"
+#include "clear_display.h"
+#include "checklogfile.h"
+#include "checkqtclogfile.h"
+#include "cw_utils.h"
+#include "fldigixmlrpc.h"
+#include "getmessages.h"
+#include "getwwv.h"
+#include "globalvars.h"		// Includes glib.h and tlf.h
+#include "initial_exchange.h"
+#include "lancode.h"
+#include "logit.h"
+#include "netkeyer.h"
+#include "parse_logcfg.h"
+#include "qtcvars.h"		// Includes globalvars.h
+#include "readctydata.h"
+#include "readcalls.h"
+#include "readqtccalls.h"
+#include "rtty.h"
+#include "rules.h"
+#include "scroll_log.h"
+#include "searchlog.h"		// Includes glib.h
+#include "sendqrg.h"		// Sets HAVE_LIBHAMLIB if enabled
 #include "set_tone.h"
 #include "splitscreen.h"
-#include "addmult.h"
-#include <termios.h>
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-#include "fldigixmlrpc.h"
+#include "startmsg.h"
+#include "tlf_panel.h"
 #include "ui_utils.h"
-#include "qtcvars.h"
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#ifdef HAVE_LIBHAMLIB
+# include <hamlib/rig.h>
+#endif
+
 
 SCREEN *mainscreen;
 SCREEN *packetscreen;
@@ -161,6 +191,7 @@ char exchange_list[40] = "";
 int timeoffset = 0;
 int multi = 0;			/* 0 = SO , 1 = MOST, 2 = MM */
 int trxmode = CWMODE;
+int rigmode = 0;		/* RIG_MODE_NONE in hamlib/rig.h, but if hamlib not compiled, then no dependecy */
 int mixedmode = 0;
 char his_rst[4] = "599";
 char my_rst[4] = "599";
@@ -358,8 +389,8 @@ int multscore[NBANDS];
 
 struct ie_list *main_ie_list;	/* head of initial exchange list */
 
-int zonescore[6];
-int countryscore[6];
+int zonescore[NBANDS];
+int countryscore[NBANDS];
 int zonedisplay = 0;
 int addzone = 0;		/* flag for new zone */
 int addcty = 0;			/* flag for new country */
@@ -420,17 +451,8 @@ int bandweight_points[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1};
 int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1};
 
 pthread_t background_thread;
-pthread_mutex_t panel_mutex = PTHREAD_MUTEX_INITIALIZER;
 static struct termios oldt, newt;
 
-/** fake old refresh code to use update logic for panels */
-void refreshp() {
-    pthread_mutex_lock( &panel_mutex );
-    update_panels();
-    doupdate();
-    pthread_mutex_unlock( &panel_mutex );
-}
-
 /** parse program options
  */
 void parse_options(int argc, char *argv[])
@@ -617,12 +639,17 @@ int databases_load()
 	return EXIT_FAILURE;
     }
 
-    mults_possible = g_ptr_array_new();
 
     if (multlist == 1) {
 	showmsg("reading multiplier data      ");
-	load_multipliers();
+	if (strlen(multsfile) == 0) {
+	    mvprintw(9, 0, "No multiplier file specified, exiting.. !!\n");
+	    refreshp();
+	    sleep(5);
+	    exit(1);
+	}
     }
+    init_and_load_multipliers();
 
     showmsg("reading callmaster data");
     load_callmaster();
