@@ -17,17 +17,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include "muf.h"
-#include "tlf.h"
-#include "ui_utils.h"
-#include "get_time.h"
-#include "dxcc.h"
-#include "sunup.h"
-#include <panel.h>
+
+
 #include <math.h>
+#include <string.h>
+#include <time.h>
+
+#include "dxcc.h"
+#include "get_time.h"
+#include "sunup.h"
+#include "tlf.h"
+#include "tlf_panel.h"
+#include "ui_utils.h"
 
 #define RADIAN		(180.0 / M_PI)
 
+
 extern double r;
 extern int m;
 extern struct tm *time_ptr;
