@@ -23,13 +23,15 @@
 	 * *--------------------------------------------------------------
 	 */
 
-#include "show_help.h"
-#include "tlf.h"
-#include "ui_utils.h"
-#include "clear_display.h"
-#include <glib.h>
+
+#include <stdlib.h>
+#include <unistd.h>
+
 #include <glib/gstdio.h>
 
+#include "clear_display.h"
+#include "tlf_curses.h"
+
 #define new_help 	/* new implementation */
 #ifdef new_help
 
