@@ -21,13 +21,17 @@
 	 *
 	 *--------------------------------------------------------------*/
 
-#include "showpxmap.h"
-#include "tlf.h"
-#include "multiplierinfo.h"
+
+#include <string.h>
+
 #include "dxcc.h"
 #include "focm.h"
+#include "changepars.h"
+#include "tlf.h"
+#include "tlf_curses.h"
 #include "ui_utils.h"
 
+
 int show_mults(void)
 {
     extern int countries[MAX_DATALINES];
@@ -97,32 +101,7 @@ int show_mults(void)
 		    if (i == iMax)
 		  	 break;
 
-		    switch (bandinx) {
-		    case BANDINDEX_160:{
-			    bandmask = BAND160;
-			    break;
-			}
-		    case BANDINDEX_80:{
-			    bandmask = BAND80;
-			    break;
-			}
-		    case BANDINDEX_40:{
-			    bandmask = BAND40;
-			    break;
-			}
-		    case BANDINDEX_20:{
-			    bandmask = BAND20;
-			    break;
-			}
-		    case BANDINDEX_15:{
-			    bandmask = BAND15;
-			    break;
-			}
-		    case BANDINDEX_10:{
-			    bandmask = BAND10;
-			    break;
-			}
-		    }
+		    bandmask = inxes[bandinx];
 
 		    if ((countries[i] & bandmask) == 0) {
 			prefix[0] = '\0';
